==> ochusha-0.4.10.2.tar.bz2: ochusha-0.4.10.2/lib/marshal.h <==

#ifndef __libochusha_marshal_MARSHAL_H__
#define __libochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* OBJECT:STRING (marshal.list:1) */
extern void libochusha_marshal_OBJECT__STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* OBJECT:INT,STRING,STRING (marshal.list:2) */
extern void libochusha_marshal_OBJECT__INT_STRING_STRING (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:POINTER (marshal.list:3) */
#define libochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING (marshal.list:4) */
#define libochusha_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:VOID (marshal.list:5) */
#define libochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:INT,INT (marshal.list:6) */
extern void libochusha_marshal_VOID__INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:INT,STRING (marshal.list:7) */
extern void libochusha_marshal_VOID__INT_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,POINTER (marshal.list:8) */
extern void libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

G_END_DECLS

#endif /* __libochusha_marshal_MARSHAL_H__ */

==> ochusha-0.5.tar.bz2: ochusha-0.5/lib/marshal.h <==

#ifndef __libochusha_marshal_MARSHAL_H__
#define __libochusha_marshal_MARSHAL_H__

#include	<glib-object.h>

G_BEGIN_DECLS

/* OBJECT:STRING (./marshal.list:1) */
extern void libochusha_marshal_OBJECT__STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
                                               const GValue *param_values,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);

/* OBJECT:INT,STRING,STRING (./marshal.list:2) */
extern void libochusha_marshal_OBJECT__INT_STRING_STRING (GClosure     *closure,
                                                          GValue       *return_value,
                                                          guint         n_param_values,
                                                          const GValue *param_values,
                                                          gpointer      invocation_hint,
                                                          gpointer      marshal_data);

/* VOID:POINTER (./marshal.list:3) */
#define libochusha_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER

/* VOID:STRING (./marshal.list:4) */
#define libochusha_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING

/* VOID:VOID (./marshal.list:5) */
#define libochusha_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID

/* VOID:INT,INT (./marshal.list:6) */
extern void libochusha_marshal_VOID__INT_INT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
                                              const GValue *param_values,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);

/* VOID:INT,STRING (./marshal.list:7) */
extern void libochusha_marshal_VOID__INT_STRING (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
                                                 const GValue *param_values,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);

/* VOID:OBJECT,POINTER (./marshal.list:8) */
extern void libochusha_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
                                                     const GValue *param_values,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);

G_END_DECLS

#endif /* __libochusha_marshal_MARSHAL_H__ */
